@@ -97,25 +97,25 @@ MainWindow::MainWindow():
 
     const QSettings config;
 
-    showVolumeMetersCheckButton->setChecked(config.value("window/showVolumeMeters", true).toBool());
+    showVolumeMetersCheckButton->setChecked(config.value(QStringLiteral("window/showVolumeMeters"), true).toBool());
 
-    const QSize last_size  = config.value("window/size").toSize();
+    const QSize last_size  = config.value(QStringLiteral("window/size")).toSize();
     if (last_size.isValid())
         resize(last_size);
 
-    const QVariant sinkInputTypeSelection = config.value("window/sinkInputType");
+    const QVariant sinkInputTypeSelection = config.value(QStringLiteral("window/sinkInputType"));
     if (sinkInputTypeSelection.isValid())
         sinkInputTypeComboBox->setCurrentIndex(sinkInputTypeSelection.toInt());
 
-    const QVariant sourceOutputTypeSelection = config.value("window/sourceOutputType");
+    const QVariant sourceOutputTypeSelection = config.value(QStringLiteral("window/sourceOutputType"));
     if (sourceOutputTypeSelection.isValid())
         sourceOutputTypeComboBox->setCurrentIndex(sourceOutputTypeSelection.toInt());
 
-    const QVariant sinkTypeSelection = config.value("window/sinkType");
+    const QVariant sinkTypeSelection = config.value(QStringLiteral("window/sinkType"));
     if (sinkTypeSelection.isValid())
         sinkTypeComboBox->setCurrentIndex(sinkTypeSelection.toInt());
 
-    const QVariant sourceTypeSelection = config.value("window/sourceType");
+    const QVariant sourceTypeSelection = config.value(QStringLiteral("window/sourceType"));
     if (sourceTypeSelection.isValid())
         sourceTypeComboBox->setCurrentIndex(sourceTypeSelection.toInt());
 
@@ -126,12 +126,12 @@ MainWindow::MainWindow():
 
 MainWindow::~MainWindow() {
     QSettings config;
-    config.setValue("window/size", size());
-    config.setValue("window/sinkInputType", sinkInputTypeComboBox->currentIndex());
-    config.setValue("window/sourceOutputType", sourceOutputTypeComboBox->currentIndex());
-    config.setValue("window/sinkType", sinkTypeComboBox->currentIndex());
-    config.setValue("window/sourceType", sourceTypeComboBox->currentIndex());
-    config.setValue("window/showVolumeMeters", showVolumeMetersCheckButton->isChecked());
+    config.setValue(QStringLiteral("window/size"), size());
+    config.setValue(QStringLiteral("window/sinkInputType"), sinkInputTypeComboBox->currentIndex());
+    config.setValue(QStringLiteral("window/sourceOutputType"), sourceOutputTypeComboBox->currentIndex());
+    config.setValue(QStringLiteral("window/sinkType"), sinkTypeComboBox->currentIndex());
+    config.setValue(QStringLiteral("window/sourceType"), sourceTypeComboBox->currentIndex());
+    config.setValue(QStringLiteral("window/showVolumeMeters"), showVolumeMetersCheckButton->isChecked());
 
     while (!clientNames.empty()) {
         auto i = clientNames.begin();
@@ -177,7 +177,7 @@ static void updatePorts(DeviceWidget *w, std::map<QByteArray, PortInfo> &ports)
 }
 
 static void setIconByName(QLabel* label, const char* name) {
-    QIcon icon = QIcon::fromTheme(name);
+    QIcon icon = QIcon::fromTheme(QString::fromUtf8(name));
     int size = label->style()->pixelMetric(QStyle::PM_ToolBarIconSize);
     QPixmap pix = icon.pixmap(size, size);
     label->setPixmap(pix);
@@ -202,7 +202,7 @@ void MainWindow::updateCard(const pa_card_info &info) {
 
     description = pa_proplist_gets(info.proplist, PA_PROP_DEVICE_DESCRIPTION);
     w->name = description ? description : info.name;
-    w->nameLabel->setText(w->name);
+    w->nameLabel->setText(QString::fromUtf8(w->name));
 
     icon = pa_proplist_gets(info.proplist, PA_PROP_DEVICE_ICON_NAME);
     setIconByName(w->iconImage, icon ? icon : "audio-card");
@@ -329,10 +329,10 @@ bool MainWindow::updateSink(const pa_sink_info &info) {
     w->description = info.description;
     w->type = info.flags & PA_SINK_HARDWARE ? SINK_HARDWARE : SINK_VIRTUAL;
 
-    w->boldNameLabel->setText("");
-    gchar *txt;
-    w->nameLabel->setText(txt = g_markup_printf_escaped("%s", info.description));
-    w->nameLabel->setToolTip(info.description);
+    w->boldNameLabel->setText(QLatin1String(""));
+    gchar *txt = g_markup_printf_escaped("%s", info.description);
+    w->nameLabel->setText(QString::fromUtf8(static_cast<char*>(txt)));
+    w->nameLabel->setToolTip(QString::fromUtf8(info.description));
     g_free(txt);
 
     icon = pa_proplist_gets(info.proplist, PA_PROP_DEVICE_ICON_NAME);
@@ -495,10 +495,10 @@ void MainWindow::updateSource(const pa_source_info &info) {
     w->description = info.description;
     w->type = info.monitor_of_sink != PA_INVALID_INDEX ? SOURCE_MONITOR : (info.flags & PA_SOURCE_HARDWARE ? SOURCE_HARDWARE : SOURCE_VIRTUAL);
 
-    w->boldNameLabel->setText("");
-    gchar *txt;
-    w->nameLabel->setText(txt = g_markup_printf_escaped("%s", info.description));
-    w->nameLabel->setToolTip(info.description);
+    w->boldNameLabel->setText(QLatin1String(""));
+    gchar *txt = g_markup_printf_escaped("%s", info.description);
+    w->nameLabel->setText(QString::fromUtf8(static_cast<char*>(txt)));
+    w->nameLabel->setToolTip(QString::fromUtf8(info.description));
     g_free(txt);
 
     icon = pa_proplist_gets(info.proplist, PA_PROP_DEVICE_ICON_NAME);
@@ -616,16 +616,16 @@ void MainWindow::updateSinkInput(const pa_sink_input_info &info) {
 
     char *txt;
     if (clientNames.count(info.client)) {
-        w->boldNameLabel->setText(txt = g_markup_printf_escaped("<b>%s</b>", clientNames[info.client]));
+        w->boldNameLabel->setText(QString::fromUtf8(txt = g_markup_printf_escaped("<b>%s</b>", clientNames[info.client])));
         g_free(txt);
-        w->nameLabel->setText(txt = g_markup_printf_escaped(": %s", info.name));
+        w->nameLabel->setText(QString::fromUtf8(txt = g_markup_printf_escaped(": %s", info.name)));
         g_free(txt);
     } else {
-        w->boldNameLabel->setText("");
-        w->nameLabel->setText(info.name);
+        w->boldNameLabel->setText(QLatin1String(""));
+        w->nameLabel->setText(QString::fromUtf8(info.name));
     }
 
-    w->nameLabel->setToolTip(info.name);
+    w->nameLabel->setToolTip(QString::fromUtf8(info.name));
 
     setIconFromProplist(w->iconImage, info.proplist, "audio-card");
 
@@ -672,16 +672,16 @@ void MainWindow::updateSourceOutput(const pa_source_output_info &info) {
 
     char *txt;
     if (clientNames.count(info.client)) {
-        w->boldNameLabel->setText(txt = g_markup_printf_escaped("<b>%s</b>", clientNames[info.client]));
+        w->boldNameLabel->setText(QString::fromUtf8(txt = g_markup_printf_escaped("<b>%s</b>", clientNames[info.client])));
         g_free(txt);
-        w->nameLabel->setText(txt = g_markup_printf_escaped(": %s", info.name));
+        w->nameLabel->setText(QString::fromUtf8(txt = g_markup_printf_escaped(": %s", info.name)));
         g_free(txt);
     } else {
-        w->boldNameLabel->setText("");
-        w->nameLabel->setText(info.name);
+        w->boldNameLabel->setText(QLatin1String(""));
+        w->nameLabel->setText(QString::fromUtf8(info.name));
     }
 
-    w->nameLabel->setToolTip(info.name);
+    w->nameLabel->setToolTip(QString::fromUtf8(info.name));
 
     setIconFromProplist(w->iconImage, info.proplist, "audio-input-microphone");
 
@@ -708,7 +708,7 @@ void MainWindow::updateClient(const pa_client_info &info) {
 
         if (w->clientIndex == info.index) {
             gchar *txt;
-            w->boldNameLabel->setText(txt = g_markup_printf_escaped("<b>%s</b>", info.name));
+            w->boldNameLabel->setText(QString::fromUtf8(txt = g_markup_printf_escaped("<b>%s</b>", info.name)));
             g_free(txt);
         }
     }
@@ -755,8 +755,8 @@ bool MainWindow::createEventRoleWidget() {
     eventRoleWidget->role = "sink-input-by-media-role:event";
     eventRoleWidget->setChannelMap(cm, true);
 
-    eventRoleWidget->boldNameLabel->setText("");
-    eventRoleWidget->nameLabel->setText(tr("System Sounds").toUtf8().constData());
+    eventRoleWidget->boldNameLabel->setText(QLatin1String(""));
+    eventRoleWidget->nameLabel->setText(tr("System Sounds"));
 
     setIconByName(eventRoleWidget->iconImage, "multimedia-volume-control");
 
