@@ -16,10 +16,10 @@
     <message>
         <location filename="../cardwidget.ui" line="47"/>
         <source>Profile:</source>
-        <translation></translation>
+        <translation>Profil:</translation>
     </message>
     <message>
-        <location filename="../cardwidget.cc" line="68"/>
+        <location filename="../cardwidget.cc" line="67"/>
         <source>pa_context_set_card_profile_by_index() failed</source>
         <translation>A „pa_context_set_card_profile_by_index()” függvényhívás meghiúsult</translation>
     </message>
@@ -41,7 +41,7 @@
     <message>
         <location filename="../channel.cc" line="160"/>
         <source>&lt;small&gt;Silence&lt;/small&gt;</source>
-        <translation>&lt;small&gt;Csöndes&lt;/small&gt;</translation>
+        <translation>&lt;small&gt;Csendes&lt;/small&gt;</translation>
     </message>
     <message>
         <location filename="../channel.cc" line="160"/>
@@ -64,17 +64,17 @@
     <message>
         <location filename="../channelwidget.ui" line="14"/>
         <source>Form</source>
-        <translation type="unfinished"></translation>
+        <translation>Űrlap</translation>
     </message>
     <message>
         <location filename="../channelwidget.ui" line="20"/>
         <source>&lt;b&gt;left-front&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&lt;b&gt;bal-elöl&lt;/b&gt;</translation>
     </message>
     <message>
         <location filename="../channelwidget.ui" line="34"/>
         <source>&lt;small&gt;50%&lt;/small&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&lt;small&gt;50%&lt;/small&gt;</translation>
     </message>
 </context>
 <context>
@@ -325,48 +325,48 @@
     </message>
     <message>
         <location filename="../mainwindow.cc" line="163"/>
-        <location filename="../mainwindow.cc" line="258"/>
+        <location filename="../mainwindow.cc" line="257"/>
         <source> (unavailable)</source>
         <translation> (elérhetetlen)</translation>
     </message>
     <message>
         <location filename="../mainwindow.cc" line="165"/>
-        <location filename="../mainwindow.cc" line="255"/>
+        <location filename="../mainwindow.cc" line="254"/>
         <source> (unplugged)</source>
         <translation> (nem csatlakoztatott)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="389"/>
+        <location filename="../mainwindow.cc" line="388"/>
         <source>Failed to read data from stream</source>
         <translation>Az adatok olvasása meghiúsult az adatfolyamból</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="433"/>
+        <location filename="../mainwindow.cc" line="432"/>
         <source>Peak detect</source>
         <translation>Csúcsérzékelés</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="434"/>
+        <location filename="../mainwindow.cc" line="433"/>
         <source>Failed to create monitoring stream</source>
         <translation>A megfigyelő adatfolyam létrehozása meghiúsult</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="449"/>
+        <location filename="../mainwindow.cc" line="448"/>
         <source>Failed to connect monitoring stream</source>
         <translation>A megfigyelő adatfolyam csatlakoztatása meghiúsult</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="588"/>
+        <location filename="../mainwindow.cc" line="587"/>
         <source>Ignoring sink-input due to it being designated as an event and thus handled by the Event widget</source>
         <translation>A nyelő bemenet nincs figyelembevéve, mivel ezt az &quot;eseménykezelő&quot; végzi</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="760"/>
+        <location filename="../mainwindow.cc" line="759"/>
         <source>System Sounds</source>
         <translation>Rendszerhangok</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="1090"/>
+        <location filename="../mainwindow.cc" line="1089"/>
         <source>Establishing connection to PulseAudio. Please wait...</source>
         <translation>Kapcsolódás a PulseAudio-hoz. Türelem...</translation>
     </message>
@@ -517,7 +517,7 @@
         <location filename="../pavucontrol.cc" line="584"/>
         <location filename="../pavucontrol.cc" line="635"/>
         <source>Connection failed, attempting reconnect</source>
-        <translation>Csatlakozás sikertelen, újrapróbáljuk</translation>
+        <translation>Csatlakozás sikertelen, újrapróbálkozás</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="607"/>
@@ -534,7 +534,7 @@ or default-server in client.conf is misconfigured.
 This situation can also arrise when PulseAudio crashed and left stale details in the X11 Root Window.
 If this is the case, then PulseAudio should autospawn again, or if this is not configured you should
 run start-pulseaudio-x11 manually.</source>
-        <translation>A PulseAudio csatlakozás sikertelen. Automata újra próbálkozás 5 mp.múlva
+        <translation type="unfinished">A PulseAudio csatlakozás sikertelen. Automata újra próbálkozás 5 mp.múlva
 
 Lehet, hogy a PULSE_SERVER az X11 Root Window Tulajdonság ablakban
 , vagy a client.conf -ban a z alapértelmezett szerver nincs jól van beállítva.
@@ -545,12 +545,12 @@ pulseaoudio-x11 -et elindítani.</translation>
     <message>
         <location filename="../pavucontrol.cc" line="672"/>
         <source>Select a specific tab on load.</source>
-        <translation>Válaszd a megfelelő fület a betöltéshez.</translation>
+        <translation>Válaszd a megfelelő lapot a betöltéshez.</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="675"/>
         <source>Retry forever if pa quits (every 5 seconds).</source>
-        <translation>MIndig újrapróbálkozik, ha a pa kilép (5 másodpercenként).</translation>
+        <translation>MIndig újrapróbálkozik, ha a PA kilép (5 másodpercenként).</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="678"/>
@@ -560,7 +560,7 @@ pulseaoudio-x11 -et elindítani.</translation>
     <message>
         <location filename="../pavucontrol.cc" line="703"/>
         <source>Fatal Error: Unable to connect to PulseAudio</source>
-        <translation>Végzetes hiba: A PulseAudo csatlakozás sikertelen</translation>
+        <translation>Végzetes hiba: A PulseAudio csatlakozás sikertelen</translation>
     </message>
 </context>
 <context>
@@ -601,7 +601,7 @@ pulseaoudio-x11 -et elindítani.</translation>
     <message>
         <location filename="../sinkinputwidget.cc" line="89"/>
         <source>pa_context_kill_sink_input() failed</source>
-        <translation>pa_context_kill_sink_input() meghiúsu</translation>
+        <translation>pa_context_kill_sink_input() meghiúsult</translation>
     </message>
     <message>
         <location filename="../sinkinputwidget.cc" line="114"/>
@@ -640,7 +640,7 @@ pulseaoudio-x11 -et elindítani.</translation>
 <context>
     <name>SourceOutputWidget</name>
     <message>
-        <location filename="../sourceoutputwidget.cc" line="36"/>
+        <location filename="../sourceoutputwidget.cc" line="35"/>
         <source>from</source>
         <translation>bemenet</translation>
     </message>
@@ -703,7 +703,7 @@ pulseaoudio-x11 -et elindítani.</translation>
     <message>
         <location filename="../streamwidget.ui" line="14"/>
         <source>Form</source>
-        <translation>Ürlap</translation>
+        <translation>Űrlap</translation>
     </message>
     <message>
         <location filename="../streamwidget.ui" line="32"/>
